@@ -3,12 +3,14 @@ import pickle
 from typing import Optional
 
 from drkns.configunit.ConfigUnit import ConfigUnit
-from drkns.configunit.StepExecutionStatus import StepExecutionStatus
+from drkns.stepexecutionstatus.StepExecutionStatus import StepExecutionStatus
 from drkns.context.Context import context
 from drkns.context.get_unit_step_path import get_unit_step_path
 
 
-def get_past_execution_status(config_unit: ConfigUnit, step_name: str) \
+def get_past_execution_status(
+        config_unit: ConfigUnit,
+        step_name: str) \
         -> Optional[StepExecutionStatus]:
     persistence_path = get_unit_step_path(config_unit, step_name)
 
